<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>CreateFolderDialog</name>
    <message>
        <location filename="../qml/Dialogs/CreateFolderDialog.qml" line="28"/>
        <source>New folder name</source>
        <translation>新建文件夹名称</translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/CreateFolderDialog.qml" line="55"/>
        <source>New folder</source>
        <translation>新建文件夹</translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/CreateFolderDialog.qml" line="81"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/CreateFolderDialog.qml" line="87"/>
        <source>OK</source>
        <translation>确定</translation>
    </message>
</context>
<context>
    <name>DateHelper</name>
    <message>
        <location filename="../helper/datehelper.cpp" line="15"/>
        <source>Now</source>
        <translation>现在</translation>
    </message>
    <message>
        <location filename="../helper/datehelper.cpp" line="17"/>
        <source>1 minute ago</source>
        <translation>一分钟前</translation>
    </message>
    <message>
        <location filename="../helper/datehelper.cpp" line="19"/>
        <source>%1 minutes ago</source>
        <translation>%1分钟前</translation>
    </message>
    <message>
        <location filename="../helper/datehelper.cpp" line="23"/>
        <source>1 hour ago</source>
        <translation>一小时前</translation>
    </message>
    <message>
        <location filename="../helper/datehelper.cpp" line="25"/>
        <source>%1 hours ago</source>
        <translation>%1小时前</translation>
    </message>
    <message>
        <location filename="../helper/datehelper.cpp" line="29"/>
        <source>1 day ago</source>
        <translation>一天前</translation>
    </message>
    <message>
        <location filename="../helper/datehelper.cpp" line="31"/>
        <source>%1 days ago</source>
        <translation>%1天前</translation>
    </message>
</context>
<context>
    <name>DeleteDialog</name>
    <message>
        <location filename="../qml/Dialogs/DeleteDialog.qml" line="47"/>
        <source>Do you want to delete it permanently?</source>
        <translation>是否要永久删除？</translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/DeleteDialog.qml" line="56"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/DeleteDialog.qml" line="62"/>
        <source>Delete</source>
        <translation>删除</translation>
    </message>
</context>
<context>
    <name>DesktopView</name>
    <message>
        <location filename="../desktop/desktopview.cpp" line="46"/>
        <source>Desktop</source>
        <translation>桌面</translation>
    </message>
</context>
<context>
    <name>EmptyTrashDialog</name>
    <message>
        <location filename="../qml/Dialogs/EmptyTrashDialog.qml" line="30"/>
        <source>File Manager</source>
        <translation>文件管理器</translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/EmptyTrashDialog.qml" line="77"/>
        <source>Do you want to permanently delete all files from the Trash?</source>
        <translation>是否要从回收站中永久删除所有文件？</translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/EmptyTrashDialog.qml" line="86"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/EmptyTrashDialog.qml" line="92"/>
        <source>Empty Trash</source>
        <translation>清空回收站</translation>
    </message>
</context>
<context>
    <name>FilePropertiesDialog</name>
    <message>
        <location filename="../dialogs/filepropertiesdialog.cpp" line="192"/>
        <source>Properties</source>
        <translation>属性</translation>
    </message>
    <message>
        <location filename="../dialogs/filepropertiesdialog.cpp" line="245"/>
        <source>%1 files</source>
        <translation>%1 项</translation>
    </message>
</context>
<context>
    <name>FolderModel</name>
    <message>
        <location filename="../model/foldermodel.cpp" line="295"/>
        <source>%1 item</source>
        <translation>%1 项</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="295"/>
        <source>%1 items</source>
        <translation>%1 项</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="400"/>
        <source>The file or folder %1 does not exist.</source>
        <translation>文件或文件夹 %1 不存在</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1256"/>
        <source>Select All</source>
        <translation>全选</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1373"/>
        <source>File Manager</source>
        <translation>文件管理器</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1691"/>
        <source>Open</source>
        <translation>打开</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1694"/>
        <source>Open with</source>
        <translation>打开方式</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1697"/>
        <source>Cut</source>
        <translation>剪切</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1700"/>
        <source>Copy</source>
        <translation>复制</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1703"/>
        <source>Paste</source>
        <translation>粘贴</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="898"/>
        <location filename="../model/foldermodel.cpp" line="1706"/>
        <source>New Folder</source>
        <translation>新建文件夹</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="920"/>
        <location filename="../model/foldermodel.cpp" line="1710"/>
        <source>New Text</source>
        <translation>新建文本</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1259"/>
        <location filename="../model/foldermodel.cpp" line="1709"/>
        <source>New Documents</source>
        <translation>新建文档</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1714"/>
        <source>Move To Trash</source>
        <translation>移动到回收站</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1717"/>
        <source>Empty Trash</source>
        <translation>清空回收站</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1720"/>
        <source>Delete</source>
        <translation>删除</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1723"/>
        <source>Rename</source>
        <translation>重命名</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1726"/>
        <source>Open in Terminal</source>
        <translation>在终端中打开</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1729"/>
        <source>Set as Wallpaper</source>
        <translation>设置为壁纸</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1732"/>
        <source>Properties</source>
        <translation>属性</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1735"/>
        <source>Change background</source>
        <translation>更改桌面背景</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1738"/>
        <source>Restore</source>
        <translation>恢复</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1741"/>
        <source>Show hidden files</source>
        <translation>显示隐藏文件</translation>
    </message>
    <message>
        <location filename="../model/foldermodel.cpp" line="1746"/>
        <source>Open in new window</source>
        <translation>在新窗口中打开</translation>
    </message>
</context>
<context>
    <name>FolderPage</name>
    <message>
        <location filename="../qml/FolderPage.qml" line="147"/>
        <source>Empty folder</source>
        <translation>空文件夹</translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="200"/>
        <source>Open</source>
        <translation>打开</translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="64"/>
        <location filename="../qml/FolderPage.qml" line="205"/>
        <source>Properties</source>
        <translation>属性</translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="54"/>
        <source>File</source>
        <translation>文件</translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="57"/>
        <source>New Folder</source>
        <translation>新建文件夹</translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="71"/>
        <source>Quit</source>
        <translation>退出</translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="77"/>
        <source>Edit</source>
        <translation>编辑</translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="80"/>
        <source>Select All</source>
        <translation>全选</translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="87"/>
        <source>Cut</source>
        <translation>剪切</translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="92"/>
        <source>Copy</source>
        <translation>复制</translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="97"/>
        <source>Paste</source>
        <translation>粘贴</translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="103"/>
        <source>Help</source>
        <translation>帮助</translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="106"/>
        <source>About</source>
        <translation>关于</translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="114"/>
        <source>File Manager</source>
        <translation>文件管理器</translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="115"/>
        <source>A file manager designed for CutefishOS.</source>
        <translation>专为 CutefishOS 打造的文件管理器</translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="268"/>
        <source>%1 item</source>
        <translation>%1 项</translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="269"/>
        <source>%1 items</source>
        <translation>%1 项</translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="275"/>
        <source>%1 selected</source>
        <translation>选中了 %1 项</translation>
    </message>
    <message>
        <location filename="../qml/FolderPage.qml" line="300"/>
        <source>Empty Trash</source>
        <translation>清空回收站</translation>
    </message>
</context>
<context>
    <name>OpenWithDialog</name>
    <message>
        <location filename="../qml/Dialogs/OpenWithDialog.qml" line="80"/>
        <source>No applications</source>
        <translation>没有应用程序</translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/OpenWithDialog.qml" line="144"/>
        <source>Set as default</source>
        <translation>设置为默认</translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/OpenWithDialog.qml" line="159"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/OpenWithDialog.qml" line="168"/>
        <source>Open</source>
        <translation>打开</translation>
    </message>
    <message>
        <location filename="../dialogs/openwithdialog.cpp" line="32"/>
        <source>Open With</source>
        <translation>打开方式</translation>
    </message>
</context>
<context>
    <name>OptionsMenu</name>
    <message>
        <location filename="../qml/OptionsMenu.qml" line="47"/>
        <source>Icons</source>
        <translation>图标视图</translation>
    </message>
    <message>
        <location filename="../qml/OptionsMenu.qml" line="85"/>
        <source>List</source>
        <translation>列表视图</translation>
    </message>
    <message>
        <location filename="../qml/OptionsMenu.qml" line="127"/>
        <source>Name</source>
        <translation>名称</translation>
    </message>
    <message>
        <location filename="../qml/OptionsMenu.qml" line="165"/>
        <source>Date</source>
        <translation>日期</translation>
    </message>
    <message>
        <location filename="../qml/OptionsMenu.qml" line="189"/>
        <source>Type</source>
        <translation>类型</translation>
    </message>
    <message>
        <location filename="../qml/OptionsMenu.qml" line="227"/>
        <source>Size</source>
        <translation>大小</translation>
    </message>
</context>
<context>
    <name>PlacesModel</name>
    <message>
        <location filename="../model/placesmodel.cpp" line="39"/>
        <source>Home</source>
        <translation>主文件夹</translation>
    </message>
    <message>
        <location filename="../model/placesmodel.cpp" line="47"/>
        <source>Desktop</source>
        <translation>桌面</translation>
    </message>
    <message>
        <location filename="../model/placesmodel.cpp" line="55"/>
        <source>Documents</source>
        <translation>文档</translation>
    </message>
    <message>
        <location filename="../model/placesmodel.cpp" line="63"/>
        <source>Downloads</source>
        <translation>下载</translation>
    </message>
    <message>
        <location filename="../model/placesmodel.cpp" line="71"/>
        <source>Music</source>
        <translation>音乐</translation>
    </message>
    <message>
        <location filename="../model/placesmodel.cpp" line="79"/>
        <source>Pictures</source>
        <translation>图片</translation>
    </message>
    <message>
        <location filename="../model/placesmodel.cpp" line="87"/>
        <source>Videos</source>
        <translation>视频</translation>
    </message>
    <message>
        <location filename="../model/placesmodel.cpp" line="93"/>
        <source>Trash</source>
        <translation>回收站</translation>
    </message>
    <message>
        <location filename="../model/placesmodel.cpp" line="117"/>
        <location filename="../model/placesmodel.cpp" line="288"/>
        <source>Drives</source>
        <translation>设备</translation>
    </message>
    <message>
        <location filename="../model/placesmodel.cpp" line="169"/>
        <source>Computer</source>
        <translation>计算机</translation>
    </message>
</context>
<context>
    <name>PropertiesDialog</name>
    <message>
        <location filename="../qml/Dialogs/PropertiesDialog.qml" line="100"/>
        <source>Type:</source>
        <translation>类型:</translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/PropertiesDialog.qml" line="113"/>
        <source>Location:</source>
        <translation>位置:</translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/PropertiesDialog.qml" line="124"/>
        <source>Size:</source>
        <translation>大小:</translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/PropertiesDialog.qml" line="131"/>
        <source>Calculating...</source>
        <translation>计算中...</translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/PropertiesDialog.qml" line="135"/>
        <source>Created:</source>
        <translation>创建时间:</translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/PropertiesDialog.qml" line="148"/>
        <source>Modified:</source>
        <translation>修改时间:</translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/PropertiesDialog.qml" line="161"/>
        <source>Accessed:</source>
        <translation>访问时间:</translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/PropertiesDialog.qml" line="183"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../qml/Dialogs/PropertiesDialog.qml" line="189"/>
        <source>OK</source>
        <translation>确定</translation>
    </message>
</context>
<context>
    <name>SideBar</name>
    <message>
        <location filename="../qml/SideBar.qml" line="126"/>
        <source>Open</source>
        <translation>打开</translation>
    </message>
    <message>
        <location filename="../qml/SideBar.qml" line="137"/>
        <source>Open in new window</source>
        <translation>在新窗口中打开</translation>
    </message>
    <message>
        <location filename="../qml/SideBar.qml" line="151"/>
        <source>Eject</source>
        <translation>弹出</translation>
    </message>
    <message>
        <location filename="../qml/SideBar.qml" line="164"/>
        <source>Unmount</source>
        <translation>卸载</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../qml/main.qml" line="35"/>
        <source>File Manager</source>
        <translation>文件管理器</translation>
    </message>
</context>
</TS>
